rstms-cloudflare
================


![Image](https://img.shields.io/github/license/rstms/rstms_cloudflare)

![Image](https://img.shields.io/pypi/v/rstms_cloudflare.svg)





Cloudflare DNS management CLI


* Free software: MIT license
* Documentation: https://rstms-cloudflare.readthedocs.io.



Credits
-------

This package was created with Cookiecutter and `rstms/cookiecutter-python-cli`, a fork of the `audreyr/cookiecutter-pypackage` project template.

[audreyr/cookiecutter](https://github.com/audreyr/cookiecutter)
[audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage)
[rstms/cookiecutter-python-cli](https://github.com/rstms/cookiecutter-python-cli)
